Class: Google::Apis::CloudlocationfinderV1::ListCloudLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudlocationfinderV1::ListCloudLocationsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudlocationfinder_v1/classes.rb,
lib/google/apis/cloudlocationfinder_v1/representations.rb,
lib/google/apis/cloudlocationfinder_v1/representations.rb
Overview
Message for response to listing cloud locations.
Instance Attribute Summary collapse
-
#cloud_locations ⇒ Array<Google::Apis::CloudlocationfinderV1::CloudLocation>
Output only.
-
#next_page_token ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCloudLocationsResponse
constructor
A new instance of ListCloudLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCloudLocationsResponse
Returns a new instance of ListCloudLocationsResponse.
108 109 110 |
# File 'lib/google/apis/cloudlocationfinder_v1/classes.rb', line 108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_locations ⇒ Array<Google::Apis::CloudlocationfinderV1::CloudLocation>
Output only. List of cloud locations.
Corresponds to the JSON property cloudLocations
98 99 100 |
# File 'lib/google/apis/cloudlocationfinder_v1/classes.rb', line 98 def cloud_locations @cloud_locations end |
#next_page_token ⇒ String
Output only. The continuation token, used to page through large result sets.
Provide this value in a subsequent request as page_token in subsequent
requests to retrieve the next page. If this field is not present, there are no
subsequent results.
Corresponds to the JSON property nextPageToken
106 107 108 |
# File 'lib/google/apis/cloudlocationfinder_v1/classes.rb', line 106 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
113 114 115 116 |
# File 'lib/google/apis/cloudlocationfinder_v1/classes.rb', line 113 def update!(**args) @cloud_locations = args[:cloud_locations] if args.key?(:cloud_locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |